# Load main library
library(hivEstimatesAccuracy)

# Define input data path
inputDataFilePath <- "d:/Drive/Projects/19. PZH/Scripts/Received/20171013/InputData/EL.csv"

# Read input data
originalData <- ReadDataFile(inputDataFilePath)

# Get preliminary attributes mapping
attrMapping <- GetPreliminaryAttributesMapping(originalData)
# Adjust mapping
attrMapping[["FirstCD4Count"]] <- "cd4_num"

# Pre-process data
inputData <- ApplyAttributesMapping(originalData, attrMapping)
inputDataValidityInfo <- ValidateInputData(inputData)
inputData <- PreProcessInputData(inputData)

# Generete missingness summary plot
PlotMissingnessSummary(inputData)

# Read adjustment specifications. Take a specific one, "Multiple imputation"
adjustmentFilePaths <- GetAdjustmentSpecFileNames()
adjustmentSpecs <- list(
  GetListObject(adjustmentFilePaths["Multiple Imputations (mice)"]),
  GetListObject(adjustmentFilePaths["Reporting Delays"])
)

# Run diagnostic (on the first adjustment only, this is for illustration)
RenderReportForAdjSpec(adjustmentSpecs[[1]], "diagnostic")
RenderReportForAdjSpec(adjustmentSpecs[[2]], "diagnostic")

# Run adjustments
adjustedData <- RunAdjustments(data = inputData,
                               adjustmentSpecs = adjustmentSpecs)
intermReport <- ""
for (i in seq_len(length(adjustmentSpecs))) {
  intermReport <- paste(intermReport,
                        RenderReportForAdjSpec(adjustmentSpecs[[i]],
                                               "intermediate",
                                               adjustedData[[i]]))
}
HTML(intermReport)

# Take the last adjustment output as final data
finalData <- adjustedData[[length(adjustedData)]]

# Write output
outputDataFilePath <- CreateOutputFileName(inputDataFilePath,
                                           suffix = paste0("_", GetTimeStamp()))
WriteDataFile(finalData$Table, outputDataFilePath)

# Create report
reportFilePaths <- GetReportFileNames()
params <- list(AdjustedData = finalData)
reportFileName <- CreateReport(reportFilePaths["Multiple Imputations"],
                               format = "html_fragment",
                               params = params)

reportFileName <- CreateReport(reportFilePaths["Multiple Imputations"],
                               format = "html_document",
                               params = params)

reportFileName <- CreateReport(reportFilePaths["Multiple Imputations"],
                               format = "pdf_document",
                               params = params)

reportFileName <- CreateReport(reportFilePaths["Multiple Imputations"],
                               format = "word_document",
                               params = params)
