# Module globals
# NONE

# User interface
dataSummaryUI <- function(id)
{
  ns <- NS(id)

  tagList(
    box(
      width = 12,
      title = "Missing data overview",
      solidHeader = TRUE,
      status = "primary",
      plotOutput(ns("missingPlot"))
    ),
    box(
      width = 12,
      title = "Validation data summary",
      solidHeader = TRUE,
      status = "primary",
      uiOutput(ns("validSummary"))
    )
  )
}

# Server logic
dataSummary <- function(input, output, session, inputData)
{
  output[["missingPlot"]] <- renderPlot({
    # Respond to inputData change
    inputData <- inputData()

    isolate({
      PlotMissingnessSummary(inputData)
    })
  })

  output[["validSummary"]] <- renderUI({
    # Respond to inputData change
    inputData <- inputData()

    isolate({
      inputDataValidityInfo <- ValidateInputData(inputData)

      inputDataValid <- all(sapply(inputDataValidityInfo, "[[", "Valid"))
      wrongValuesCols <- Filter(function(x) length(x$WrongValues) != 0, inputDataValidityInfo)

      headerHTML <- NULL
      textColor <- NULL
      if (inputDataValid) {
        textColor <- "green"
        headerHTML <- p("Data is valid. It contains only valid values.", style = paste("color:", textColor))
      } else {
        textColor <- "red"
        headerHTML <- p("Data is not valid. Please, correct the following issues:", style = paste("color:", textColor))
      }

      wrongValuesHTML <- NULL
      if (length(wrongValuesCols) > 0) {
        wrongValuesHTML <- tags$li(
          "Incorrect values:",
          tags$ul(
            lapply(names(wrongValuesCols), function(colName) {
              wrongValuesCol <- wrongValuesCols[[colName]]
              tags$li(paste(AddQuoteMarks(colName),
                            "contains invalid value(s)",
                            paste(AddQuoteMarks(wrongValuesCol$WrongValues), collapse = ", ")))
            })
          )
        )
      }

      validationSummaryHTML <- tagList(headerHTML,
                                       tags$ol(wrongValuesHTML,
                                               style = paste("color:", textColor)))



      return(validationSummaryHTML)
    })
  })
}
